@@ -217,6 +217,7 @@ gboolean midgard_collector_set_key_property(
 	MidgardCoreQueryConstraint *constraint = midgard_core_query_constraint_new();
 	midgard_core_query_constraint_set_builder(constraint, self->priv->builder);
 	midgard_core_query_constraint_set_class(constraint, klass);
+	GdaConnection *cnc = self->priv->mgd->priv->connection;
 
 	if(!midgard_core_query_constraint_parse_property(&constraint, klass, key)) {
 		
@@ -233,8 +234,11 @@ gboolean midgard_collector_set_key_property(
 		return FALSE;
 	}
 
-	gchar *sql_field = g_strconcat(constraint->priv->current->table, ".",
-			constraint->priv->current->field, " AS midgard_collector_key", NULL);
+	gchar *q_table = gda_connection_quote_sql_identifier (cnc, constraint->priv->current->table);
+	gchar *q_field = gda_connection_quote_sql_identifier (cnc, constraint->priv->current->field);
+	gchar *sql_field = g_strconcat(q_table, ".", q_field, " AS midgard_collector_key", NULL);
+	g_free (q_table);
+	g_free (q_field);
 	
 	g_object_unref(constraint);
 
@@ -293,6 +297,7 @@ gboolean midgard_collector_add_value_property(
 	MidgardCoreQueryConstraint *constraint = midgard_core_query_constraint_new();
 	midgard_core_query_constraint_set_builder(constraint, self->priv->builder);
 	midgard_core_query_constraint_set_class(constraint, klass);
+	GdaConnection *cnc = self->priv->mgd->priv->connection;
 
 	if(!midgard_core_query_constraint_parse_property(&constraint, klass, value)) {
 		
@@ -309,10 +314,14 @@ gboolean midgard_collector_add_value_property(
 		return FALSE;
 	}
 
-	gchar *sql_field = g_strconcat(constraint->priv->current->table, ".",
-			constraint->priv->current->field, " AS ",
-			constraint->priv->pspec->name, NULL);
-	
+	gchar *q_table = gda_connection_quote_sql_identifier (cnc, constraint->priv->current->table);
+	gchar *q_field = gda_connection_quote_sql_identifier (cnc, constraint->priv->current->field);
+	gchar *q_name = gda_connection_quote_sql_identifier (cnc, constraint->priv->pspec->name);
+	gchar *sql_field = g_strconcat (q_table, ".", q_field, " AS ", q_name, NULL);
+	g_free (q_table);
+	g_free (q_field);
+	g_free (q_name);
+
 	g_object_unref(constraint);
 	self->priv->values =
 		g_list_prepend(self->priv->values, sql_field);
@@ -898,21 +907,21 @@ midgard_collector_execute (MidgardCollector *self)
 
 				g_value_init(new_value, MGD_TYPE_TIMESTAMP);
 				g_value_transform(gda_value, new_value);
-
-			} else if (GDA_VALUE_HOLDS_BINARY(gda_value)) {
-
+			
+			} else if (G_VALUE_TYPE (gda_value) == GDA_TYPE_BLOB) {
+				gchar *stringified = midgard_core_query_binary_stringify ((GValue*)gda_value);
 				g_value_init(new_value, G_TYPE_STRING);
-				gchar *bstr = gda_binary_to_string(gda_value_get_binary(gda_value), 0);
-				g_value_set_string(new_value, bstr);
-				g_free(bstr);
-
+				g_value_take_string(new_value, stringified);
+			} else if (G_VALUE_TYPE (gda_value) == G_TYPE_STRING) {		
+				g_value_init(new_value, G_TYPE_STRING);
+				g_value_take_string(new_value, g_value_dup_string (gda_value));
 			} else {
-
 				g_value_init(new_value, G_TYPE_STRING);
 				if(!G_VALUE_HOLDS_STRING(gda_value))
 					g_value_transform(gda_value, new_value);
 				else
 					g_value_copy(gda_value, new_value);
+				
 			}
 
 			ck_value = g_new0(GValue, 1);
