@@ -43,7 +43,7 @@
 #define MGD_MYSQL_PASSWORD "midgard"
 
 gboolean 
-__midgard_connection_open (MidgardConnection *mgd, GHashTable **hashtable, gboolean init_schema);
+__midgard_connection_open (MidgardConnection *mgd, gboolean init_schema, GError **error);
 
 static MidgardConnectionPrivate *
 midgard_connection_private_new (void)
@@ -53,6 +53,7 @@ midgard_connection_private_new (void)
 
 	cnc_private->pattern = NULL;	
 	cnc_private->config = NULL;
+	cnc_private->copy_config = NULL;
 	cnc_private->connected = FALSE;
 	cnc_private->loghandler = 0;
 	cnc_private->loglevel = 0;	
@@ -124,6 +125,10 @@ static void _midgard_connection_finalize(GObject *object)
 		}
 	}
 
+	if (self->priv->copy_config)
+		g_object_unref (self->priv->copy_config);
+	self->priv->copy_config = NULL;
+
 	g_free(self->priv);
 	self->priv = NULL;
 }
@@ -206,8 +211,13 @@ _midgard_connection_get_property (GObject *object, guint property_id,
 		case PROPERTY_CONFIG:
 			if (!self->priv->config)
 				return;
+			if (self->priv->copy_config) {
+				g_value_set_object (value, self->priv->copy_config);
+				return;
+			}
 			MidgardConfig *config = midgard_config_copy (self->priv->config);
 			g_object_set (config, "dbuser", "", "dbpass", "", NULL);
+			self->priv->copy_config = config;
 			g_value_set_object (value, config);
 			break;
 
@@ -387,7 +397,8 @@ __mysql_reconnect (MidgardConnection *mgd)
 	gda_connection_close_no_warning (mgd->priv->connection);
 	g_signal_emit (mgd, MIDGARD_CONNECTION_GET_CLASS (mgd)->signal_id_disconnected, 0);
 
-	/* Try to reconnect 3 times */
+	/* Try to reconnect 10 times */
+	guint n_times = 10;
 	do {
 		g_usleep (5000000); /* 5 seconds interval */
 		g_debug ("Trying to reopen connection");
@@ -403,7 +414,7 @@ __mysql_reconnect (MidgardConnection *mgd)
 
 		i++;
 
-	} while (i < 3);
+	} while (i < n_times);
 
 	return FALSE;
 }
@@ -486,11 +497,11 @@ static void cnc_add_part(
 #endif
 }
 
-gboolean __midgard_connection_open(
-		MidgardConnection *mgd, 
-		GHashTable **hashtable, gboolean init_schema)
+gboolean 
+__midgard_connection_open(MidgardConnection *mgd, gboolean init_schema, GError **error)
 {
 	g_return_val_if_fail(mgd != NULL, FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
 	MIDGARD_ERRNO_SET (mgd, MGD_ERR_OK);
 
@@ -583,16 +594,16 @@ gboolean __midgard_connection_open(
 #endif
 	}
 
-	GError *error = NULL;
+	GError *err = NULL;
 #ifdef HAVE_LIBGDA_4
 	GdaConnection *connection = gda_connection_open_from_string(
-			config->dbtype, tmpstr, auth, GDA_CONNECTION_OPTIONS_NONE, &error);
+			config->dbtype, tmpstr, auth, GDA_CONNECTION_OPTIONS_NONE, &err);
 
 	g_free(auth);	
 #else
 	GdaClient *client =  gda_client_new();
 	GdaConnection *connection = gda_client_open_connection_from_string(
-			client, config->dbtype, tmpstr, NULL, NULL, 0, &error);
+			client, config->dbtype, tmpstr, NULL, NULL, 0, &err);
 	mgd->priv->cnc_str = g_strdup(tmpstr);
 	mgd->priv->auth_str = NULL;
 #endif
@@ -600,12 +611,14 @@ gboolean __midgard_connection_open(
 	if(connection == NULL) {
 
 		MIDGARD_ERRNO_SET_STRING (mgd, MGD_ERR_NOT_CONNECTED, 
-				" Database [%s]. %s", tmpstr, error->message);
-
+				" Database [%s]. %s", tmpstr, err->message);
+		if (err) {
+			*error = g_error_new (MGD_GENERIC_ERROR, MGD_ERR_NOT_CONNECTED, 
+					"Database [%s]. %s", tmpstr, err->message);
+			g_clear_error (&err);
+		}
 		g_free(tmpstr);
-
 		return FALSE;
-	
 	} 
 
 	g_free(tmpstr);
@@ -686,13 +699,13 @@ midgard_connection_open (MidgardConnection *self, const char *name, GError **err
 	if (!rv)
 		return rv;	
 
-	/* FIXME, it should be handled by GError */
 	if(self->priv->config != NULL){
 		midgard_set_error(self,
 				MGD_GENERIC_ERROR,
 				MGD_ERR_USER_DATA,
 				"MidgardConfig already associated with "
 				"MidgardConnection");
+		*error = g_error_new (MGD_GENERIC_ERROR, MGD_ERR_INTERNAL, "%s", midgard_connection_get_error_string (self));
 		return FALSE;
 	}
 	
@@ -708,20 +721,16 @@ midgard_connection_open (MidgardConnection *self, const char *name, GError **err
 		return FALSE;
 	}
 	
-	if(error)
-		g_clear_error(&rf_error);
-
 	self->priv->config = config;
 
-	GHashTable *hash = NULL;
-
-	if(!__midgard_connection_open(self, &hash, TRUE)) {
+	GError *err = NULL;
+	if(!__midgard_connection_open(self, TRUE, &err)) {
 
 		MIDGARD_ERRNO_SET (self, MGD_ERR_NOT_CONNECTED);
 		rv = FALSE;
+		if (err)
+			g_propagate_error (error, err);
 	}
-
-	g_hash_table_destroy(hash);
 	
 	return rv;
 }
@@ -773,18 +782,14 @@ gboolean midgard_connection_open_from_file(
 		return FALSE;
 	}
 	
-	if(error)
-		g_clear_error(&rf_error);
-
 	mgd->priv->config = config;
 
-	GHashTable *hash = NULL;
-
-	if(!__midgard_connection_open(mgd, &hash, TRUE)) 
+	GError *err = NULL;
+	if(!__midgard_connection_open(mgd, TRUE, &err)) 
 		rv = FALSE;
 
-	if(hash)
-		g_hash_table_destroy(hash);
+	if (err)
+		g_propagate_error (error, err);
 	
 	return rv;
 }
@@ -802,7 +807,6 @@ extern GHashTable *midgard_connection_open_all(gboolean userdir)
 {
 	GHashTable *cncs = 
 		g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_object_unref);
-	GHashTable *hash = NULL;
 
 	gchar **cfgs = midgard_config_list_files(userdir);
 	
@@ -832,9 +836,12 @@ extern GHashTable *midgard_connection_open_all(gboolean userdir)
 
 		cnc->priv->config = config;
 
-		if(__midgard_connection_open(cnc, &hash, TRUE)) {
+		GError *err = NULL;
+		if(__midgard_connection_open(cnc, TRUE, &err)) {
 
 			g_hash_table_insert(cncs, g_strdup(cfgs[i]), cnc);
+			if (err)
+				g_clear_error (&err);
 		
 		} else {
 			
@@ -844,9 +851,6 @@ extern GHashTable *midgard_connection_open_all(gboolean userdir)
 		
 		i++;
 	}
-	
-	if(hash)
-		g_hash_table_destroy(hash);
 
 	g_strfreev(cfgs);
 	
@@ -893,13 +897,11 @@ gboolean midgard_connection_open_config(
 
 	self->priv->config = midgard_config_copy (config);
 
-	GHashTable *hash = NULL;
-
-	if(!__midgard_connection_open(self, &hash, TRUE))
+	GError *err = NULL;
+	if(!__midgard_connection_open(self, TRUE, &err))
 		rv = FALSE;
-
-	if(hash)
-		g_hash_table_destroy(hash);
+	if (err)
+		g_clear_error (&err);
 
 	return rv;
 }
@@ -912,9 +914,13 @@ gboolean midgard_connection_struct_open_config(
 	
 	self->priv->config = config;
 	
-	if(!__midgard_connection_open(self, NULL, FALSE))
+	GError *err = NULL;
+	if(!__midgard_connection_open(self, FALSE, &err)) {
+		if (err)
+			g_clear_error (&err);
 		return FALSE;
-	
+	}
+
 	return TRUE;
 }
 
@@ -1166,7 +1172,10 @@ gboolean midgard_connection_reopen(MidgardConnection *self)
 
 				case MIDGARD_DB_TYPE_MYSQL:
 
-					if (errcode == 2006) { /* CR_SERVER_GONE_ERROR , we can not use it */
+					/* For some, unknown reason GDA sets unknown error code for MySQL provider */
+					/* Take into account MySQL's server gone error and gda's unknown one */
+					if (errcode == 2006 /* CR_SERVER_GONE_ERROR , we can not use it */
+							|| errcode == GDA_CONNECTION_EVENT_CODE_UNKNOWN) { 
 						g_debug("MySQL server has gone away. Reconnect.");
 						return __mysql_reconnect(self);
 					}
