@@ -696,7 +696,7 @@ midgard_core_query_create_dbobject_record (MidgardDBObject *object)
 
 	GdaStatement *insert = MIDGARD_DBOBJECT_GET_CLASS (object)->dbpriv->statement_insert;
 	g_return_val_if_fail (insert != NULL, FALSE);
-	GdaSet *params = MIDGARD_DBOBJECT_GET_CLASS (object)->dbpriv->param_set_insert;
+	GdaSet *params = MIDGARD_DBOBJECT_GET_CLASS (object)->dbpriv->statement_insert_params;
 
 	guint n_props;
 	guint i;	
@@ -885,325 +885,59 @@ midgard_core_query_create_dbobject_record (MidgardDBObject *object)
 
 #endif /* HAVE_LIBGDA_4 */
 
-#ifdef HAVE_LIBGDA_4
-
 gboolean 
 midgard_core_query_update_dbobject_record (MidgardDBObject *object)
 {
 	g_return_val_if_fail (object != NULL, FALSE);
-
-	MidgardConnection *mgd = MGD_OBJECT_CNC (object);	
+	
+	MidgardConnection *mgd = MGD_OBJECT_CNC (object);
 	GdaConnection *cnc = mgd->priv->connection;
-	g_return_val_if_fail (cnc != NULL, FALSE);
-
-	MidgardDBObjectClass *klass = g_type_class_peek (G_OBJECT_TYPE (object));
+	MidgardDBObjectClass *klass = MIDGARD_DBOBJECT_GET_CLASS (object);
 	if (!klass) {
 		g_warning ("Can not find class pointer for %s instance", G_OBJECT_TYPE_NAME (object));
 		return FALSE;
 	}
 
-	const gchar *table = midgard_core_class_get_table (klass);
-	if (!table) {
-		g_warning ("Empty table for %s class", G_OBJECT_TYPE_NAME (object));
-		return FALSE;
-	}
+	GdaStatement *update = MIDGARD_DBOBJECT_GET_CLASS (object)->dbpriv->statement_update;
+	g_return_val_if_fail (update != NULL, FALSE);
+	GdaSet *params = MIDGARD_DBOBJECT_GET_CLASS (object)->dbpriv->statement_update_params;
 
-	guint n_prop;
-	guint i;
-	GParamSpec **pspecs = g_object_class_list_properties (G_OBJECT_CLASS (klass), &n_prop);
-	if (!pspecs) {
-		g_warning ("Properties not registered for %s class", G_OBJECT_TYPE_NAME (object));
-		return FALSE;
-	}
+	guint n_props;
+	guint i;	
+	GParamSpec **pspecs = midgard_core_dbobject_class_list_properties (klass, &n_props);
+	g_return_val_if_fail (pspecs != NULL, FALSE);
 
-	const gchar *guid = MGD_OBJECT_GUID (object);
-	if (!guid || (guid && *guid == '\0')) {
-		g_warning ("Can not update object with empty guid");
-		return FALSE;
-	}
-
-	GString *sql = g_string_new ("UPDATE ");
-	g_string_append_printf (sql, "%s SET ", table);
-
-	MgdSchemaPropertyAttr *prop_attr = NULL;	
-	GValue value = {0, };
-	gboolean add_coma = FALSE;
-
-	for (i = 0; i < n_prop; i++) {
-
-		/* Map property to storage field */
-		prop_attr = midgard_core_class_get_property_attr (klass, pspecs[i]->name);
-		if (!prop_attr || (prop_attr && !prop_attr->field)) {
-			if (i == 1)
-				add_coma = FALSE;
-			continue;
-		}
-
-		g_value_init (&value, pspecs[i]->value_type);
-		g_object_get_property (G_OBJECT (object), pspecs[i]->name, &value);
-	
-		/* Convert boolean to integer, it's safe for SQLite at least */
-		/*if (pspecs[i]->value_type == G_TYPE_BOOLEAN) {
-
-			bv = g_value_get_boolean (&value);
-			g_value_unset (&value);
-
-			g_value_init (&value, G_TYPE_UINT);
-			g_value_set_uint (&value, bv ? 1 : 0);
-		}*/
-
-		_add_value_type_update (sql, (const gchar *) prop_attr->field, &value, add_coma);
-		g_value_unset (&value);
-
-		add_coma = TRUE;
-	}
-
-	g_string_append_printf (sql, " WHERE %s.guid = '%s'", table, guid);  		
-
-	/* Create statement and set parameters */
-	GdaSqlParser *parser = (MGD_OBJECT_CNC (object))->priv->parser;
-	GdaStatement *stmt;
-	GdaSet *params;
-	GdaHolder *p;
+	const gchar *pk = midgard_reflector_object_get_property_primary (G_OBJECT_CLASS_NAME (klass));
 	GError *error = NULL;
 
-	stmt = gda_sql_parser_parse_string (parser, sql->str, NULL, &error);
-
-	if (!stmt || error) {
-
-		g_warning ("%s. Failed to create SQL statement for given query %s", 
-				error && error->message ? error->message : "Unknown reason", sql->str);
-		if (stmt)
-			g_object_unref (stmt);
-
-		g_clear_error (&error);
-		return FALSE;
-	}
-
-	g_string_free (sql, TRUE);
-	if (!gda_statement_get_parameters (stmt, &params, &error)) {
-	
-		g_warning ("Failed to get query parameters. %s", error && error->message ? error->message : "Unknown reason");
-		g_object_unref (stmt);
-		if (error) g_clear_error (&error);
-		return FALSE;
-	}
-
-	for (i = 0; i < n_prop; i++) {
-
-		prop_attr = midgard_core_class_get_property_attr (klass, pspecs[i]->name);
-		if (!prop_attr || (prop_attr && !prop_attr->field))
+	for (i = 0; i < n_props; i++) {
+		/* Ignore primary key and property of GObject type*/
+		if ((pk && g_str_equal (pspecs[i]->name, pk)) || 
+				G_TYPE_FUNDAMENTAL(pspecs[i]->value_type) == G_TYPE_OBJECT)
 			continue;
-	
-		const gchar *prop_field = prop_attr->field;
 
-		p = gda_set_get_holder (params, prop_field);
-	
-		if (!p)
-			g_warning ("%s: Failed to get holder for %s column", __FUNCTION__, (gchar *) prop_field);
-
-		/* FIXME, optimize this, we got property in previous loop */	
-		g_value_init (&value, pspecs[i]->value_type);
-		g_object_get_property (G_OBJECT (object), pspecs[i]->name, &value);
-
-		if (!gda_holder_set_value (p, &value, &error)) {
-			g_warning ("Failed to set holder's value. %s", 
-					error && error->message ? error->message : "Unknown reason");
-			g_object_unref (stmt);
-			if (error) g_clear_error (&error);
-			return FALSE;
-		}
-
-		g_value_unset (&value);
+		const gchar *col_name = midgard_core_class_get_property_colname (klass, pspecs[i]->name);
+		_SET_HOLDER_VALUE;
 	}
 
+	__add_metadata_parameters (object, klass, params);
+
 	if (MGD_CNC_DEBUG (mgd)) {
-		gchar *debug_sql = gda_connection_statement_to_sql (cnc, stmt, params, GDA_STATEMENT_SQL_PRETTY, NULL, NULL);
-		g_debug ("%s", debug_sql);
+		gchar *debug_sql = gda_connection_statement_to_sql (cnc, update, params, GDA_STATEMENT_SQL_PRETTY, NULL, NULL);
+		g_debug ("DBObject update: %s", debug_sql);
 		g_free (debug_sql);
 	}
 
-	gint retval = gda_connection_statement_execute_non_select (cnc, stmt, params, NULL, &error);
+	gboolean updated = (gda_connection_statement_execute_non_select (cnc, update, params, NULL, &error) == -1) ? FALSE : TRUE;
 
-	if (error) {
-		g_warning ("Failed to execute statement. %s", error && error->message ? error->message : "Unknown reason");
-		g_clear_error (&error);
-	}
-	
-	g_free (pspecs);
-	g_object_unref (params);
-	g_object_unref (stmt);
-
-	if (retval == -1) {
-
-		/* FIXME, provider error, handle this */
+	if (!updated) {
+		g_warning ("Query failed. %s", error && error->message ? error->message : "Unknown reason");
 		return FALSE;
 	}
 
-	if (retval >= 0)
-		return TRUE;
-
-	return FALSE;
-
+	return updated;
 }
 
-#else
-
-gboolean 
-midgard_core_query_update_dbobject_record (MidgardDBObject *object)
-{
-	g_return_val_if_fail (object != NULL, FALSE);
-	
-	GdaConnection *cnc = (MGD_OBJECT_CNC (object))->priv->connection;
-	g_return_val_if_fail (cnc != NULL, FALSE);
-
-	MidgardDBObjectClass *klass = g_type_class_peek (G_OBJECT_TYPE (object));
-	if (!klass) {
-
-		g_warning ("Can not find class pointer for %s instance", G_OBJECT_TYPE_NAME (object));
-		return FALSE;
-	}
-
-	const gchar *table = midgard_core_class_get_table (klass);
-	if (!table) {
-		
-		g_warning ("Empty table for %s class", G_OBJECT_TYPE_NAME (object));
-		return FALSE;
-	}
-
-	guint n_prop;
-	guint i;
-	GParamSpec **pspecs = g_object_class_list_properties (G_OBJECT_CLASS (klass), &n_prop);
-
-	if (!pspecs) {
-		
-		g_warning ("Properties not registered for %s class", G_OBJECT_TYPE_NAME (object));
-		return FALSE;
-	}
-
-	const gchar *guid = MGD_OBJECT_GUID (object);
-	if (!guid || (guid && *guid == '\0')) {
-
-		g_warning ("an not update object with empty guid");
-		return FALSE;
-	}
-
-	GdaDict *dict = gda_dict_new ();
-        gda_dict_set_connection (dict , (MGD_OBJECT_CNC (object))->priv->connection);
-
-	GString *sqlquery = g_string_new ("UPDATE ");
-	g_string_append_printf (sqlquery, "%s SET ", table);
-
-	MgdSchemaPropertyAttr *prop_attr = NULL;
-	gboolean bv;
-
-	/* Create parameters from properties */
-	GParameter *parameters = g_new0 (GParameter, n_prop);
-
-	for (i = 0; i < n_prop; i++) {
-		
-		GValue value = {0, };
-		g_value_init (&value, pspecs[i]->value_type);
-		g_object_get_property (G_OBJECT (object), pspecs[i]->name, &value);
-		/* Map property to storage field */
-		prop_attr = midgard_core_class_get_property_attr (klass, pspecs[i]->name);
-
-		/* Convert boolean to integer, it's safe for SQLite at least */
-		if (pspecs[i]->value_type == G_TYPE_BOOLEAN) {
-
-			bv = g_value_get_boolean (&value);
-			g_value_unset (&value);
-
-			g_value_init (&value, G_TYPE_UINT);
-			g_value_set_uint (&value, bv ? 1 : 0);
-		}
-
-		parameters[i].name = prop_attr->field;
-		parameters[i].value = (const GValue)value;
-		g_string_append_printf (sqlquery, "%s %s=", i > 0 ? "," : "", prop_attr->field);
-		_add_value_type (sqlquery, parameters[i].name, &parameters[i].value, FALSE);
-		g_value_unset (&value);
-	}
-
-	g_string_append_printf (sqlquery, " WHERE %s.guid = '%s'", table, guid);  	
-
-	GError *error = NULL;
-        GdaQuery *query = gda_query_new_from_sql (dict, sqlquery->str, &error);
-
-	g_string_free (sqlquery, TRUE);
-
-	if (query) 
-		g_debug ("%s", gda_query_get_sql_text (query));
-
-        if (!query || error) {
-		
-		g_warning ("Failed to create new query from string. %s", error && error->message ? error->message : "Unknown reason");
-
-		if (query)
-			g_object_unref (query);
-
-		g_object_unref (dict);
-		g_free (pspecs);
-		
-		return FALSE;
-	}
-
-	GdaParameterList *plist = gda_query_get_parameter_list (query);
-	GdaParameter *param;
-
-	for (i = 0; i < n_prop; i++) {
-
-		/* Map property to storage field */
-		prop_attr = midgard_core_class_get_property_attr (klass, pspecs[i]->name);
-		param = gda_parameter_list_find_param (plist, prop_attr->field);
-		GValue val = {0, };
-		g_value_init (&val, pspecs[i]->value_type);
-		g_object_get_property (G_OBJECT(object), pspecs[i]->name, &val);
-		
-		/* Convert boolean to integer, it's safe for SQLite at least */
-		if (pspecs[i]->value_type == G_TYPE_BOOLEAN) {
-
-			bv = g_value_get_boolean (&val);
-			g_value_unset (&val);
-
-			g_value_init (&val, G_TYPE_UINT);
-			g_value_set_uint (&val, bv ? 1 : 0);
-		}
-
-		gda_parameter_set_value (param, (const GValue*) &val);
-	}
-
-	gda_connection_clear_events_list (cnc);
-
-	g_free (pspecs);
-	g_object_unref (dict);
-
-	if (error)
-		g_clear_error (&error);
-	error = NULL;
-
-	/* TODO , debug query */
-	GdaObject *res_object = gda_query_execute (query, plist, FALSE, &error);
-
-	g_object_unref (query);
-	g_object_unref (plist);
-
-	if (!res_object)
-		return FALSE;
-
-	g_object_unref (res_object);
-
-	if (error) {
-
-		g_warning ("Failed to update object record. %s", error && error->message ? error->message : "Unknown reason");
-		return FALSE;
-	}
-
-	return TRUE;
-}
-
-# endif /* HAVE_LIBGDA_4 */
-
 #ifdef HAVE_LIBGDA_4
 
 gboolean 
@@ -1821,17 +1555,17 @@ static gboolean __mcq_column_exists(MidgardConnection *mgd,
         g_value_set_string ((mcontext.column_values[0] = gda_value_new (G_TYPE_STRING)), mdc->table_name);
         g_value_set_string ((mcontext.column_values[1] = gda_value_new (G_TYPE_STRING)), mdc->column_name);
 	GError *error = NULL;
-	if (!gda_connection_update_meta_store (mgd->priv->connection, &mcontext, &error)) {
+	/*if (!gda_connection_update_meta_store (mgd->priv->connection, &mcontext, &error)) {
 		gda_value_free (mcontext.column_values[0]);
-		/* FIXME, there should be warning, but for some reason 
-		 * either SQLite or gda-sqlite provider is buggy */	
+		//FIXME, there should be warning, but for some reason 
+		//either SQLite or gda-sqlite provider is buggy 
 		g_message ("Failed to update meta data for table '%s': %s", mdc->table_name, 
 				error && error->message ? error->message : "No detail");
 		if (error)
 			g_error_free(error);
 
 		return FALSE;
-	}
+	}*/
 
 	GdaDataModel *dm_schema =
 		gda_connection_get_meta_store_data (mgd->priv->connection,
@@ -2840,6 +2574,12 @@ midgard_core_dbjoin_new(void)
 	mdbj->type = NULL;
 	mdbj->typeid = 0;
 	mdbj->klass = NULL;
+	mdbj->left_table = NULL;
+	mdbj->left_field = NULL;
+	mdbj->right_table = NULL;
+	mdbj->right_field = NULL;
+	mdbj->left_tablefield = NULL;
+	mdbj->right_tablefield = NULL;
 
 	/* pointers references */
 	mdbj->left = NULL;
@@ -2857,19 +2597,39 @@ void midgard_core_dbjoin_free (MidgardDBJoin *mdbj)
 
 	mdbj->typeid = 0;	
 
+	g_free (mdbj->left_table);
+	mdbj->left_table = NULL;
+	g_free (mdbj->left_field);
+	mdbj->left_field = NULL;
+	g_free (mdbj->right_table);
+	mdbj->right_table = NULL;
+	g_free (mdbj->right_field);
+	mdbj->right_field = NULL;
+	g_free (mdbj->left_tablefield);
+	mdbj->left_tablefield = NULL;
+	g_free (mdbj->right_tablefield);
+	mdbj->right_tablefield = NULL;
+
 	g_free(mdbj);
 }
 
 /* Routine which is a workaround for gda_binary_stringify, 
- *  * which is also registered as transform function which converts 
- *   * binary value to string one.
- *    * With this function we get GdaBinary->data 'as is' */
+ * which is also registered as transform function which converts 
+ * binary value to string one.
+ * With this function we get GdaBinary->data 'as is' */
 gchar *
 midgard_core_query_binary_stringify (GValue *src_value)
 {
 	g_return_val_if_fail (src_value != NULL, NULL);
 
-	const GdaBinary *binary = gda_value_get_binary ((const GValue*) src_value);
+	const GdaBinary *binary;
+	if (G_VALUE_TYPE (src_value) == GDA_TYPE_BLOB) {
+		const GdaBlob *blob = gda_value_get_blob (src_value);
+		binary = &blob->data;
+	}
+
+	if (G_VALUE_TYPE (src_value) == GDA_TYPE_BINARY) 
+		binary = gda_value_get_binary ((const GValue*) src_value);
 
 	if (binary == NULL || (binary && binary->binary_length == 0)
 			|| (binary && binary->data == NULL))
@@ -3009,6 +2769,8 @@ midgard_core_query_compute_constraint_property (MidgardQueryExecutor *executor,
 	g_return_val_if_fail (executor != NULL, FALSE);
 	g_return_val_if_fail (name != NULL, FALSE);
 
+	GdaConnection *cnc = executor->priv->mgd->priv->connection;
+
 	/* Set table alias if it's not set */
 	if (storage)
 		MQE_SET_TABLE_ALIAS (executor, storage);
@@ -3031,6 +2793,9 @@ midgard_core_query_compute_constraint_property (MidgardQueryExecutor *executor,
 	while(spltd[i] != NULL)
 		i++;
 
+	gchar *q_table = NULL;
+	gchar *q_field = NULL;
+
 	/* case: property */
 	if (i == 1) {
 		const gchar *property_field = midgard_core_class_get_property_colname (klass, name);
@@ -3039,7 +2804,11 @@ midgard_core_query_compute_constraint_property (MidgardQueryExecutor *executor,
 			g_strfreev (spltd);
 			return NULL;
 		}
-		table_field = g_strdup_printf ("%s.%s", table_alias, property_field);
+		q_table = gda_connection_quote_sql_identifier (cnc, table_alias);
+		q_field = gda_connection_quote_sql_identifier (cnc, property_field);
+		table_field = g_strdup_printf ("%s.%s", q_table, q_field);
+		g_free (q_table);
+		g_free (q_field);
 	} else if (i < 4) {
 		/* Set all pointers we need to generate valid tables' names, aliases or joins */
 		Psh holder = {NULL, };
@@ -3059,8 +2828,13 @@ midgard_core_query_compute_constraint_property (MidgardQueryExecutor *executor,
 			j++;
 		}	
 		
-		if (holder.table_alias && holder.colname)
-			table_field = g_strdup_printf ("%s.%s", holder.table_alias, holder.colname);
+		if (holder.table_alias && holder.colname) {
+			q_table = gda_connection_quote_sql_identifier (cnc, holder.table_alias);
+			q_field = gda_connection_quote_sql_identifier (cnc, holder.colname);
+			table_field = g_strdup_printf ("%s.%s", q_table, q_field);
+			g_free (q_table);
+			g_free (q_field);
+		}
 
 	} else {
 		  g_warning("Failed to parse '%s'. At most 3 tokens allowed", name);
@@ -3071,4 +2845,48 @@ midgard_core_query_compute_constraint_property (MidgardQueryExecutor *executor,
 	return table_field;
 }
 
+gchar*
+midgard_core_query_unescape_string (MidgardConnection *mgd, const gchar *string)
+{
+	glong total;
+	gchar *ptr;
+	gchar *retval;
+	glong offset = 0;
+	
+	if (!string) 
+		return NULL;
+
+	total = strlen (string);
+	retval = g_memdup (string, total+1);
+	ptr = (gchar *) retval;
+	while (offset < total) {
+
+		/* we accept the "''" as a synonym of "\'" */
+		if (*ptr == '\'') {
+			if (*(ptr+1) == '\'') {
+				g_memmove (ptr+1, ptr+2, total - offset);
+				offset += 2;
+			}
+		}
+		if (*ptr == '\\') {
+			if (*(ptr+1) == '\\') {
+				g_memmove (ptr+1, ptr+2, total - offset);
+				offset += 2;
+			}
+			else {
+				if (*(ptr+1) == '\'') {
+					*ptr = '\'';
+					g_memmove (ptr+1, ptr+2, total - offset);
+					offset += 2;
+				}				
+			}
+		}
+		else
+			offset ++;
+
+		ptr++;
+	}
+
+	return retval;		
+}
 
