@@ -50,6 +50,12 @@ struct _MidgardDBJoin {
 	guint typeid;
 	gchar *table;
 	MidgardObjectClass *klass;
+	gchar *left_table;
+	gchar *left_field;
+	gchar *right_table;
+	gchar *right_field;
+	gchar *left_tablefield;
+	gchar *right_tablefield;
 
 	/* pointers references */
 	MgdSchemaPropertyAttr *left;
@@ -267,8 +273,8 @@ gboolean midgard_core_table_exists(
 GdaDataModel 		*midgard_core_query_get_dbobject_model 		(MidgardConnection *mgd, MidgardDBObjectClass *klass, guint n_params, const GParameter *parameters);
 gboolean		midgard_core_query_create_dbobject_record 	(MidgardDBObject *object);
 gboolean		midgard_core_query_update_dbobject_record 	(MidgardDBObject *object);
-gchar                   *midgard_core_query_binary_stringify            (GValue *src_value);
+gchar                   *midgard_core_query_binary_stringify            (GValue *src_value); 
 gchar 			*midgard_core_query_compute_constraint_property	(MidgardQueryExecutor *executor, MidgardQueryStorage *storage, const gchar *name);
-
+gchar 			*midgard_core_query_unescape_string (MidgardConnection *mgd, const gchar *str);
 
 #endif /* MIDGARD_CORE_QUERY_H */
