@@ -134,6 +134,9 @@ static void __get_view_properties(xmlNode *node, MgdSchemaTypeAttr *type)
 			/* Create property attributes copy using original property.
 			   Then change name. */
 			MgdSchemaPropertyAttr *prop_attr = g_hash_table_lookup(type->prophash, property_name);
+
+			/* Keep pointer to original property attribue. At least, we need it when creating view. */
+			prop_attr->derived = rprop_attr;
 	
 			if (!prop_attr)
 				g_warning("Can not find  %s.%s in newly registered view", type->name, name); 
@@ -142,6 +145,11 @@ static void __get_view_properties(xmlNode *node, MgdSchemaTypeAttr *type)
 
 				g_free((gchar *)prop_attr->name);
 				prop_attr->name = g_strdup((gchar *)name);
+				g_free ((gchar *)prop_attr->field);
+				prop_attr->field = g_strdup((gchar *)name);
+
+				if (prop_attr->table == NULL)
+					prop_attr->table = g_strdup (table);
 
 				/* Free old key and remove new one in hash table */
 				g_hash_table_remove(type->prophash, (gconstpointer) rprop[1]);
@@ -169,6 +177,11 @@ static void __get_view_joins(xmlNode *node, MgdSchemaTypeAttr *type)
 	gchar *property_name = NULL;	
 	MgdSchemaPropertyAttr *propright = NULL;
 	MgdSchemaPropertyAttr *propleft = NULL;
+	MidgardDBObjectClass *metadata_klass = MIDGARD_DBOBJECT_CLASS (g_type_class_peek (MIDGARD_TYPE_METADATA));
+	gchar *left_table = NULL;
+	gchar *right_table = NULL;
+	gchar *left_field = NULL;
+	gchar *right_field = NULL;
 
 	for (cur = node->children; cur; cur = cur->next) {
 	
@@ -231,12 +244,29 @@ static void __get_view_joins(xmlNode *node, MgdSchemaTypeAttr *type)
 				return;
 			}
 
-			MgdSchemaPropertyAttr *propleft = 
-				g_hash_table_lookup(klass->dbpriv->storage_data->prophash, classprop[1]);
-			if (!propleft)
-				__view_error(cur, "Property %s not registered for %s", classprop[1], classprop[0]); 
-			/* __get_property_attribute (cur, classprop, &property_name, &propleft, klass); */ 
-			g_strfreev(classprop);
+			/* Set left and right table and field explicitly.
+			 * It's important to ignore  MgdSchemaPropertyAttr in case of metadata usage.
+			 * For this class, we can use explicit table and tablefield, and setting such 
+			 * for metadata's MgdSchemaPropertyAttr could break any other queries. 
+			 * Also, we need explicit table and field names for proper quoting. */
+
+			/* Check reserved metadata property */
+			if (g_str_equal (classprop[1], "metadata")) {
+				if (classprop[2] == NULL)
+					__view_error (cur, "Metadata defined without property name");
+				propleft = g_hash_table_lookup(metadata_klass->dbpriv->storage_data->prophash, classprop[2]);
+				if (!propleft)
+					__view_error(cur, "Property %s not registered for metadata class", classprop[2]);
+				left_table = g_strdup (midgard_core_class_get_table (klass));
+				left_field = g_strdup (propleft->field);
+			} else {
+				propleft = g_hash_table_lookup(klass->dbpriv->storage_data->prophash, classprop[1]);
+				if (!propleft)
+					__view_error(cur, "Property %s not registered for %s", classprop[1], classprop[0]); 
+				left_table = g_strdup (propleft->table ? propleft->table : type->table);
+				left_field = g_strdup (propleft->field);
+			}
+			g_strfreev(classprop);	
 
 			/* Get right property attribute */
 			classprop = g_strsplit_set(right, ":.", -1);
@@ -251,11 +281,22 @@ static void __get_view_joins(xmlNode *node, MgdSchemaTypeAttr *type)
 				return;
 			}
 
-			MgdSchemaPropertyAttr *propright = 
-				g_hash_table_lookup(klass->dbpriv->storage_data->prophash, classprop[1]);
-			if (!propright)
-				__view_error(cur, "Property %s not registered for %s", classprop[1], classprop[0]);
-			/* __get_property_attribute (cur, classprop, &property_name, &propright, klass); */
+			/* Check reserved metadata property */
+			if (g_str_equal (classprop[1], "metadata")) {
+				if (classprop[2] == NULL)
+					__view_error (cur, "Metadata defined without property name");
+				propright = g_hash_table_lookup(metadata_klass->dbpriv->storage_data->prophash, classprop[2]);
+				if (!propright)
+					__view_error(cur, "Property %s not registered for metadata class", classprop[2]);
+				right_table = g_strdup (midgard_core_class_get_table (klass));
+				right_field = g_strdup (propright->field);
+			} else {
+				propright = g_hash_table_lookup(klass->dbpriv->storage_data->prophash, classprop[1]);
+				if (!propright)
+					__view_error(cur, "Property %s not registered for %s", classprop[1], classprop[0]);
+				right_table = g_strdup (propright->table ? propright->table : type->table);
+				right_field = g_strdup (propright->field);
+			}
 			g_strfreev(classprop);
 
 			MidgardDBJoin *mdbj = midgard_core_dbjoin_new();
@@ -266,10 +307,15 @@ static void __get_view_joins(xmlNode *node, MgdSchemaTypeAttr *type)
 				mdbj->table = g_strdup(midgard_core_class_get_table(joinklass));
 			else 
 				mdbj->table = g_strdup((gchar *)table);
-	
+
 			mdbj->left = propleft;
 			mdbj->right = propright;
 
+			mdbj->left_table = left_table;
+			mdbj->left_field = left_field;
+			mdbj->right_table = right_table;
+			mdbj->right_field = right_field;
+
 			g_free(left);
 			g_free(right);
 
@@ -407,22 +453,42 @@ static void __mgdschematype_from_node(xmlNode *node, GSList **list)
 	xmlFree(viewname);
 }
 
-gchar *__build_static_create_view(MgdSchemaTypeAttr *type)
+gchar *
+midgard_core_view_build_create_view_command (MidgardConnection *mgd, MidgardDBObjectClass *klass)
 {
-	GString *query = g_string_new("CREATE VIEW ");	
+	GdaConnection *cnc = mgd->priv->connection;
+	GString *query = g_string_new ("CREATE VIEW ");	
+	MgdSchemaTypeAttr *type = midgard_core_class_get_type_attr (klass);
 
-	g_string_append_printf(query, "%s AS SELECT %s FROM %s ", 
-			type->name, (gchar *)type->sql_select_full, type->table);
+	klass->dbpriv->set_static_sql_select (mgd, klass);
+
+	g_string_append_printf (query, "%s AS SELECT %s FROM %s ", 
+			type->name, (gchar *)type->sql_select_full, type->view_table);
 
 	GSList *list = NULL;
 
 	for (list = type->joins; list != NULL; list = list->next) {
 	
 		MidgardDBJoin *join = (MidgardDBJoin *) list->data;
+		gchar *jtable = gda_connection_quote_sql_identifier (cnc, join->table);
+
+		gchar *q_table = gda_connection_quote_sql_identifier (cnc, join->left_table);
+		gchar *q_field = gda_connection_quote_sql_identifier (cnc, join->left_field);
+		gchar *ltf = g_strjoin (".", q_table, q_field, NULL);
+		g_free (q_table);
+		g_free (q_field);
+
+		q_table = gda_connection_quote_sql_identifier (cnc, join->right_table);
+		q_field = gda_connection_quote_sql_identifier (cnc, join->right_field);
+		gchar *rtf = g_strjoin (".", q_table, q_field, NULL);
+		g_free (q_table);
+		g_free (q_field);
+
 		g_string_append_printf(query, "%s JOIN %s ON %s = %s ", 
-				join->type, 
-				join->table, 
-				join->left->tablefield, join->right->tablefield);		
+				join->type, jtable, ltf, rtf );
+		g_free (jtable);
+		g_free (ltf);
+		g_free (rtf);
 	}	
 
 	/* Select only those records which are not deleted. #1437 */
@@ -440,7 +506,8 @@ gchar *__build_static_create_view(MgdSchemaTypeAttr *type)
 
 		MidgardDBJoin *join = (MidgardDBJoin *) list->data;
 		g_string_append_printf(query, " %s.metadata_deleted = 0 AND %s.metadata_deleted = 0 ", 
-				join->left->table, join->right->table);
+				join->left_table ? join->left_table : join->left->table, 
+				join->right_table ? join->right_table : join->right->table);
 
 		i++;
 	}
@@ -485,46 +552,13 @@ static void __register_view_type (MgdSchemaTypeAttr *type)
 					&type->class_nprop);
 
 		/* Replace storage name */
+		type->view_table = g_strdup (type->table);
 		g_hash_table_destroy(type->tableshash);
 		g_free((gchar *)type->table);
 		type->table = NULL;
 		type->tableshash = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL);
 		midgard_core_schema_type_set_table(type, (const gchar *)type->name);
 
-		/* Recreate static sql used by QB */
-		g_free(type->sql_select_full);
-		guint i;
-		GString *ssf = g_string_new("");
-		gboolean add_coma = FALSE;
-
-		for (i = 0; i < type->class_nprop; i++) {
-		
-			if (G_TYPE_FUNDAMENTAL (pspecs[i]->value_type) == G_TYPE_OBJECT) {
-				if (i == 1)
-					add_coma = FALSE;
-				continue;
-			}
-
-			if (!add_coma)
-				g_string_append(ssf, pspecs[i]->name);
-			else 
-				g_string_append_printf(ssf, ", %s", pspecs[i]->name);
-
-			add_coma = TRUE;
-
-			/* Replace tablefield for every property */
-			MgdSchemaPropertyAttr *prop_attr = g_hash_table_lookup(type->prophash, pspecs[i]->name);
-			if (!prop_attr) {
-
-				g_warning ("%s property not registered for %s", pspecs[i]->name, type->name);
-				g_error ("Failed to register view class");
-			}
-			midgard_core_schema_type_property_set_tablefield(prop_attr, type->name, pspecs[i]->name);
-		}
-
-		type->sql_select_full = ssf->str;
-		g_string_free(ssf, FALSE);
-
 		g_free(pspecs);
 		g_object_unref(foo);
 	}
@@ -574,8 +608,7 @@ void midgard_core_views_read_file(const gchar *path)
 		GSList *clist = NULL;
 		for (clist = list; clist != NULL; clist = clist->next) {
 			
-			MgdSchemaTypeAttr *type = (MgdSchemaTypeAttr *) clist->data;
-			type->sql_create_view = __build_static_create_view(type);
+			MgdSchemaTypeAttr *type = (MgdSchemaTypeAttr *) clist->data;	
 			midgard_core_schema_type_initialize_paramspec (type);
 			midgard_core_schema_type_validate_fields(type);
 			__register_view_type(type);	
