@@ -26,7 +26,7 @@ static GObjectClass *parent_class= NULL;
 
 /* Create GdaSqlSelectField for every property registered for the class. */
 void
-_add_fields_to_select_statement (MidgardDBObjectClass *klass, GdaSqlStatementSelect *select, const gchar *table_name)
+_add_fields_to_select_statement (MidgardDBObjectClass *klass, GdaConnection *cnc, GdaSqlStatementSelect *select, const gchar *table_name)
 {
 	guint n_prop;
 	guint i;
@@ -55,13 +55,17 @@ _add_fields_to_select_statement (MidgardDBObjectClass *klass, GdaSqlStatementSel
        		select_field = gda_sql_select_field_new (GDA_SQL_ANY_PART (select));
 		/*select_field->field_name = g_strdup (property_field);
 		select_field->table_name = g_strdup (property_table);*/
-		select_field->as = g_strdup (property);
+		select_field->as = gda_connection_quote_sql_identifier (cnc, property);
 		select->expr_list = g_slist_append (select->expr_list, select_field);
 		expr = gda_sql_expr_new (GDA_SQL_ANY_PART (select_field));
 		val = g_new0 (GValue, 1);
 		g_value_init (val, G_TYPE_STRING);
-		table_field = g_strconcat (property_table, ".", property_field, NULL);
+		gchar *q_table = gda_connection_quote_sql_identifier (cnc, property_table);
+		gchar *q_field = gda_connection_quote_sql_identifier (cnc, property_field);
+		table_field = g_strconcat (q_table, ".", q_field, NULL);
 		g_value_set_string (val, table_field);
+		g_free (q_table);
+		g_free (q_field);
 		g_free (table_field);
 		expr->value = val;
 		select_field->expr = expr;
@@ -78,7 +82,7 @@ _add_fields_to_select_statement (MidgardDBObjectClass *klass, GdaSqlStatementSel
 			return;
 
 		if (MIDGARD_DBOBJECT_CLASS (mklass)->dbpriv->add_fields_to_select_statement) {
-			MIDGARD_DBOBJECT_CLASS (mklass)->dbpriv->add_fields_to_select_statement (MIDGARD_DBOBJECT_CLASS (mklass), select, table_name);
+			MIDGARD_DBOBJECT_CLASS (mklass)->dbpriv->add_fields_to_select_statement (MIDGARD_DBOBJECT_CLASS (mklass), cnc, select, table_name);
 			return;
 		}
 
@@ -339,7 +343,94 @@ __initialize_statement_insert (MidgardDBObjectClass *klass)
 	}
 	
 	klass->dbpriv->statement_insert = stmt;
-	klass->dbpriv->param_set_insert = params;
+	klass->dbpriv->statement_insert_params = params;
+	
+	return;
+}
+
+static void
+__statement_update_add_metadata_fields (MidgardDBObjectClass *klass, GString *sql)
+{
+	MidgardMetadataClass *mklass = MGD_DBCLASS_METADATA_CLASS (klass);
+	if (!mklass)
+		return;
+
+	guint i;
+	guint n_prop;
+	GParamSpec **pspecs = g_object_class_list_properties (G_OBJECT_CLASS (mklass), &n_prop);
+
+	if (!pspecs)
+		return;
+
+	for (i = 0; i < n_prop; i++) {
+		const gchar *col_name = midgard_core_class_get_property_colname (MIDGARD_DBOBJECT_CLASS (mklass), pspecs[i]->name);
+		if (!col_name)
+			continue;
+		const gchar *type_name = g_type_name (pspecs[i]->value_type);
+		if (pspecs[i]->value_type == MIDGARD_TYPE_TIMESTAMP)
+			type_name = "string";
+		g_string_append_printf (sql, ", %s=##%s::%s", col_name, col_name, type_name);
+	}
+
+	g_free (pspecs);
+}
+
+static void
+__initialize_statement_update (MidgardDBObjectClass *klass)
+{
+	GString *sql = g_string_new ("");
+	guint n_props;
+	guint i;
+	const gchar *table = MGD_DBCLASS_TABLENAME (klass);
+	g_return_if_fail (table != NULL);
+
+	g_string_append_printf (sql, "UPDATE %s SET ", table); 
+
+	GParamSpec **pspecs = midgard_core_dbobject_class_list_properties (klass, &n_props);
+	g_return_if_fail (pspecs != NULL);
+
+	const gchar *pk = MGD_DBCLASS_PRIMARY (klass);
+	gboolean add_coma = FALSE;
+
+	for (i = 0; i < n_props; i++) {
+		/* Ignore primary key */
+		if (pk && g_str_equal (pspecs[i]->name, pk))
+			continue;
+
+		const gchar *col_name = midgard_core_class_get_property_colname (klass, pspecs[i]->name);
+
+		const gchar *type_name = g_type_name (pspecs[i]->value_type);
+		if (pspecs[i]->value_type == MIDGARD_TYPE_TIMESTAMP)
+			type_name = "string";
+		g_string_append_printf (sql, "%s%s=##%s::%s", add_coma ? ", " : " ", col_name, col_name, type_name);
+		add_coma = TRUE;
+	}
+
+	__statement_update_add_metadata_fields (klass, sql);
+
+	g_string_append(sql, " WHERE guid=##guid::string ");		
+	GdaSqlParser *parser = gda_sql_parser_new ();
+	GdaStatement *stmt;
+	GError *error = NULL;
+	stmt = gda_sql_parser_parse_string (parser, sql->str, NULL, &error);
+
+	g_string_free (sql, TRUE);
+
+	if (!stmt) {
+
+		g_error ("Couldn't create %s class prepared UPDATE statement. %s", 
+				G_OBJECT_CLASS_NAME (klass), error && error->message ? error->message : "Unknown reason");
+		return;
+	}
+
+	GdaSet *params; 
+	if (!gda_statement_get_parameters (stmt, &params, &error)) {
+		g_error ("Failed to create GdaSet for %s class. %s", 
+				G_OBJECT_CLASS_NAME (klass), error && error->message ? error->message : "Unknown reason");
+	}
+	
+	klass->dbpriv->statement_update = stmt;
+	klass->dbpriv->statement_update_params = params;
 	
 	return;
 }
@@ -521,6 +612,9 @@ midgard_dbobject_class_init (MidgardDBObjectClass *klass, gpointer g_class_data)
 	klass->dbpriv->set_from_data_model = _midgard_dbobject_set_from_data_model;
 	klass->dbpriv->statement_insert = NULL;
 	klass->dbpriv->set_statement_insert = __initialize_statement_insert;	
+	klass->dbpriv->statement_update = NULL;
+	klass->dbpriv->set_statement_update = __initialize_statement_update;
+	klass->dbpriv->set_static_sql_select = NULL;
 
 	/* Properties */
 	GParamSpec *pspec = g_param_spec_object ("connection",
