@@ -141,6 +141,22 @@ notified_signal_handler (DBusGProxy *proxy, const char *msg, gpointer user_data)
 
 /* API */
 
+/**
+ * midgard_dbus_is_enabled:
+ *
+ * Returns: %TRUE if Midgard library is compiled with DBUS support, %FALSE otherwise
+ *
+ * Since: 10.05.1
+ */
+gboolean
+midgard_dbus_is_enabled (void)
+{
+#ifdef MGD_HAVE_DBUS
+	return TRUE;
+#endif
+	return FALSE;
+}
+
 static void __unref_object(gpointer data, GClosure *closure)
 {
 	if (data == NULL)
@@ -208,6 +224,21 @@ midgard_dbus_new(MidgardConnection *mgd, const gchar *path, gboolean use_session
 #endif
 }
 
+/**
+ * midgard_dbus_create_dbus:
+ *
+ * Constructor. Invokes midgard_dbus_new().
+ * This function is added for language bindings, in which, midgard_dbus_new can not be 
+ * invoked explicitly.
+ *
+ * Since: 10.05.1
+ */
+MidgardDbus *
+midgard_dbus_create_dbus (MidgardConnection *mgd, const gchar *path, gboolean use_session)
+{
+	return midgard_dbus_new (mgd, path, use_session);
+}
+
 #ifdef MGD_HAVE_DBUS
 DBusGProxy*
 __get_bus_proxy(MidgardConnection *mgd, DBusGConnection *bus, const gchar *path)
