@@ -74,7 +74,10 @@ gboolean
 _midgard_query_select_set_offset (MidgardQueryExecutor *self, guint offset)
 {
 	g_return_val_if_fail (self != NULL, FALSE);
-	g_return_val_if_fail (offset > 0, FALSE);
+	if (offset < 0) {
+		g_warning ("Negative offset value not allowed. Setting default value 0");
+		offset = 0;
+	}
 
 	self->priv->offset = offset;
 
@@ -107,7 +110,7 @@ _midgard_query_select_add_order (MidgardQueryExecutor *self, MidgardQueryPropert
 
 	qso *_qs = g_new (qso, 1);
 	_qs->asc = asc;
-	_qs->property = property;
+	_qs->property = g_object_ref (property);
 
 	self->priv->orders = g_slist_append (self->priv->orders, _qs);
 
@@ -210,7 +213,12 @@ gboolean __query_select_add_orders (MidgardQueryExecutor *self)
 		order = gda_sql_select_order_new (GDA_SQL_ANY_PART (select));
 		order->asc = _so->asc;
 		MidgardQueryProperty *property = _so->property;
-		MidgardQueryStorage *storage = property->priv->storage;
+		MidgardQueryStorage *storage = NULL;
+		
+		if (property->priv && property->priv->storage)
+			storage = property->priv->storage;
+		else 
+			storage = MIDGARD_QUERY_EXECUTOR (self)->priv->storage;
 
 		/* Compute table.colname for given property name */
 		GValue rval = {0, };
@@ -404,7 +412,7 @@ _midgard_query_select_execute (MidgardQueryExecutor *self)
 	s_target->expr = texpr;
 
 	/* Add fields for all properties registered per class (SELECT a,b,c...) */
-	klass->dbpriv->add_fields_to_select_statement (klass, sss, s_target->as);
+	klass->dbpriv->add_fields_to_select_statement (klass, cnc, sss, s_target->as);
 
 	/* Add joins, LEFT JOIN tbl2 ON... */
 	if (!__query_select_add_joins (MIDGARD_QUERY_SELECT (self))) 
@@ -659,6 +667,13 @@ _midgard_query_select_finalize (GObject *object)
 	if (MIDGARD_QUERY_EXECUTOR (self)->priv->resultset && G_IS_OBJECT (MIDGARD_QUERY_EXECUTOR (self)->priv->resultset))
 		g_object_unref (MIDGARD_QUERY_EXECUTOR (self)->priv->resultset);
 
+	/* Drop the reference to QueryProperty object. Orders are freed in parent class */
+	GSList *l;
+	for (l = MIDGARD_QUERY_EXECUTOR (self)->priv->orders; l != NULL; l = l->next) {
+		qso *_so = (qso*) l->data;
+		g_object_unref (_so->property);
+	}
+
 	parent_class->finalize (object);
 }
 
