@@ -187,7 +187,7 @@ void midgard_query_builder_free(MidgardQueryBuilder *builder)
  * 
  * <para>
  * @name referes to a property of the queried Midgard object class. 
- * For example: #MidgardQueryBuilder has been initialized for person 
+ * For example, #MidgardQueryBuilder has been initialized for person 
  * class which has lastname property registered.
  * <example>
  * <programlisting>
@@ -210,7 +210,7 @@ void midgard_query_builder_free(MidgardQueryBuilder *builder)
  * <listitem><para>
  * First property is the one registered for given class which is a link
  * to property of different class. Second is a property of target class.
- * For example: person object has property 'friend' which holds some identifier
+ * For example, person object has property 'friend' which holds some identifier
  * (id or guid) to friend class property, and friend class has property 'nick'.
  * In such case we can use constraint and comparison using friend property,
  * even if #MidgardQueryBuilder has been initialized for person class.
@@ -270,15 +270,16 @@ gboolean midgard_query_builder_add_constraint(
 	midgard_core_query_constraint_set_class(constraint, MIDGARD_DBOBJECT_CLASS(g_type_class_peek(builder->priv->type)));
 	
 	if(!midgard_core_query_constraint_add_operator(constraint, op))
-		return FALSE;
+		goto return_false;
 		
 	if(!midgard_core_query_constraint_parse_property(&constraint, MIDGARD_DBOBJECT_CLASS(g_type_class_peek(builder->priv->type)), name))
-		return FALSE;
+		goto return_false;
 
 	if(!midgard_core_query_constraint_add_value(constraint, value))
-		return FALSE;
+		goto return_false;
 	
-	midgard_core_query_constraint_build_condition(constraint);
+	if (!midgard_core_query_constraint_build_condition(constraint))
+		goto return_false;
 
 	/* FIXME, table should be stored per every constraint, order, whatever */
 	midgard_core_qb_add_table(builder, constraint->priv->prop_left->table);
@@ -295,6 +296,10 @@ gboolean midgard_query_builder_add_constraint(
 	midgard_core_qb_add_constraint(builder, constraint);	
 
 	return TRUE;
+
+return_false:
+	g_object_unref (constraint);
+	return FALSE;
 }
 
 /**
@@ -342,14 +347,15 @@ gboolean midgard_query_builder_add_constraint_with_property(
 	midgard_core_query_constraint_set_class(constraint, klass);
 
 	if(!midgard_core_query_constraint_parse_property(&constraint, klass, property_a))
-		return FALSE;
+		goto return_false;
 	constraint->priv->current = constraint->priv->prop_right;
 	if(!midgard_core_query_constraint_parse_property(&constraint, klass, property_b))
-		return FALSE;
+		goto return_false;
 
 	constraint->priv->condition_operator = g_strdup(op);
 
-	midgard_core_query_constraint_build_condition(constraint);
+	if (!midgard_core_query_constraint_build_condition(constraint))
+		goto return_false;
 
 	midgard_core_qb_add_table(builder, constraint->priv->prop_left->table);
 	midgard_core_qb_add_table(builder, constraint->priv->prop_right->table);
@@ -366,6 +372,10 @@ gboolean midgard_query_builder_add_constraint_with_property(
 	}
 	
 	return TRUE;
+
+return_false:
+	g_object_unref (constraint);
+	return FALSE;
 }
 
 /**
@@ -748,7 +758,11 @@ gchar *midgard_query_builder_get_object_select(
 		/* TODO, Set select which suits better */	
 	} 
 
-	if(builder->priv->schema->sql_select_full != NULL) {
+	if (builder->priv->schema->sql_select_full == NULL
+			|| MIDGARD_DBOBJECT_CLASS (klass)->dbpriv->set_static_sql_select != NULL)
+		MIDGARD_DBOBJECT_CLASS (klass)->dbpriv->set_static_sql_select (builder->priv->mgd, MIDGARD_DBOBJECT_CLASS (klass));
+
+	if (builder->priv->schema->sql_select_full != NULL) {
 		g_string_append_printf(select, " %s", 
 				builder->priv->schema->sql_select_full);
 	}
@@ -840,18 +854,11 @@ static void __mqb_set_metadata(MidgardMetadata *mdata, GdaDataModel *model, gint
 	/* hidden */
 	gvalue = midgard_data_model_get_value_at(model, ++col, i);
 	mdata->priv->hidden = FALSE;
-	if(G_VALUE_HOLDS_BOOLEAN(gvalue)) {
-		mdata->priv->hidden = 
-			g_value_get_boolean(gvalue);
-	}
+	MIDGARD_GET_BOOLEAN_FROM_VALUE (mdata->priv->hidden, gvalue);
 
 	/* nav_noentry */
 	gvalue = midgard_data_model_get_value_at(model, ++col, i);
-	mdata->priv->nav_noentry = FALSE;
-	if(G_VALUE_HOLDS_BOOLEAN(gvalue)) {
-		mdata->priv->nav_noentry = 
-			g_value_get_boolean(gvalue);
-	}
+	MIDGARD_GET_BOOLEAN_FROM_VALUE (mdata->priv->nav_noentry, gvalue);
 
 	/* size */
 	gvalue = midgard_data_model_get_value_at(model, ++col, i);
@@ -874,11 +881,7 @@ static void __mqb_set_metadata(MidgardMetadata *mdata, GdaDataModel *model, gint
 
 	/* deleted */
 	gvalue = midgard_data_model_get_value_at(model, ++col, i);
-	mdata->priv->deleted = FALSE;
-	if(G_VALUE_HOLDS_BOOLEAN(gvalue)) {
-		mdata->priv->deleted = 
-			g_value_get_boolean(gvalue);
-	}
+	MIDGARD_GET_BOOLEAN_FROM_VALUE (mdata->priv->deleted, gvalue);
 		
 	/* score */
 	gvalue = midgard_data_model_get_value_at(model, ++col, i);
@@ -890,70 +893,16 @@ static void __mqb_set_metadata(MidgardMetadata *mdata, GdaDataModel *model, gint
 
 	/* islocked */
 	gvalue = midgard_data_model_get_value_at(model, ++col, i);
-	if(G_VALUE_HOLDS_BOOLEAN(gvalue)) {
-		mdata->priv->is_locked = 
-			g_value_get_boolean(gvalue);
-	}
+	MIDGARD_GET_BOOLEAN_FROM_VALUE (mdata->priv->is_locked, gvalue);
 
 	/* isapproved */
 	gvalue = midgard_data_model_get_value_at(model, ++col, i);
-	if(G_VALUE_HOLDS_BOOLEAN(gvalue)) {
-		mdata->priv->is_approved = 
-			g_value_get_boolean(gvalue);
-	}
+	MIDGARD_GET_BOOLEAN_FROM_VALUE (mdata->priv->is_approved, gvalue);
 
 	return;
 }
 
 
-/* based on gda_default_unescape_string */
-/* https://bugzilla.gnome.org/show_bug.cgi?id=617565 */
-gchar *
-__default_unescape_string (const gchar *string)
-{
-	glong total;
-	gchar *ptr;
-	gchar *retval;
-	glong offset = 0;
-	
-	if (!string) 
-		return NULL;
-
-	total = strlen (string);
-	retval = g_memdup (string, total+1);
-	ptr = (gchar *) retval;
-	while (offset < total) {
-
-		/* we accept the "''" as a synonym of "\'" */
-		if (*ptr == '\'') {
-			if (*(ptr+1) == '\'') {
-				g_memmove (ptr+1, ptr+2, total - offset);
-				offset += 2;
-			}
-		}
-		if (*ptr == '\\') {
-			if (*(ptr+1) == '\\') {
-				g_memmove (ptr+1, ptr+2, total - offset);
-				offset += 2;
-			}
-			else {
-				if (*(ptr+1) == '\'') {
-					*ptr = '\'';
-					g_memmove (ptr+1, ptr+2, total - offset);
-					offset += 2;
-				}				
-			}
-		}
-		else
-			offset ++;
-
-		ptr++;
-	}
-
-	return retval;	
-}
-
-
 GList *
 midgard_core_qb_set_object_from_query (MidgardQueryBuilder *builder, guint select_type, MidgardObject **nobject)
 {
@@ -1068,7 +1017,7 @@ midgard_core_qb_set_object_from_query (MidgardQueryBuilder *builder, guint selec
 				GParamSpec *pspec =
 					g_object_class_find_property(G_OBJECT_GET_CLASS(object), coltitle);
 
-				if(G_IS_VALUE(gvalue)) {
+				if(G_IS_VALUE(gvalue) && !gda_value_is_null(gvalue)) {
 
 					if (!pspec) {
 						
@@ -1077,13 +1026,13 @@ midgard_core_qb_set_object_from_query (MidgardQueryBuilder *builder, guint selec
 						continue;
 					}
 
-					if (G_VALUE_TYPE (gvalue) == GDA_TYPE_BINARY
+					if (G_VALUE_TYPE (gvalue) == GDA_TYPE_BLOB
 							&& G_TYPE_FUNDAMENTAL (pspec->value_type) == G_TYPE_STRING) {
 
-						gchar *stringified = midgard_core_query_binary_stringify ((GValue *)gvalue);
+						gchar *stringified = midgard_core_query_binary_stringify ((GValue*)gvalue);	
 						g_object_set (G_OBJECT (object), coltitle, stringified, NULL);
 				   		g_free (stringified);
-					
+				
 					} else if (pspec->value_type != G_VALUE_TYPE (gvalue)) {
 
 						GValue _convert = {0, };
@@ -1091,15 +1040,6 @@ midgard_core_qb_set_object_from_query (MidgardQueryBuilder *builder, guint selec
 				
 						if (g_value_transform (gvalue, &_convert)) {
 
-							/* FIXME, remove workaround once it's fixed in GDA */
-							/* https://bugzilla.gnome.org/show_bug.cgi?id=617550 */
-							guint dbtype = mgd->priv->config->priv->dbtype;
-							if (dbtype == MIDGARD_DB_TYPE_MYSQL && G_VALUE_TYPE (gvalue) == GDA_TYPE_BLOB) {
-								gchar *tmp_str = __default_unescape_string (g_value_get_string (&_convert));
-								if (tmp_str)
-									g_value_take_string (&_convert, tmp_str);
-							}
-
 							g_object_set_property (G_OBJECT (object), coltitle, &_convert);
 					
 						} else {
@@ -1123,6 +1063,7 @@ midgard_core_qb_set_object_from_query (MidgardQueryBuilder *builder, guint selec
 
 						case G_TYPE_INT:
 						case G_TYPE_UINT:
+						case G_TYPE_BOOLEAN:
 							g_object_set(G_OBJECT(object), coltitle, 0, NULL);
 							break;
 
